from AcodisApiHandler.acodis_handler import *
from AcodisApiHandler.acodis_parser import *
from AcodisApiHandler.acodis_error import *
from AcodisApiHandler._acodis_logger import *

__all__ = ['AcodisApiHandler', 'extract_tags', 'AcodisError', 'AcodisApiError', 'AcodisAuthError', 'AcodisParsingError']

if __name__ == '__main__':
    print("version is: " + __version__)


class AcodisError(Exception):
    def __init__(self, message):
        """General class for Acodis-related errors"""
        super().__init__(message)


class AcodisApiError(AcodisError):
    def __init__(self, message):
        """Class for Acodis API-related errors"""
        super().__init__(message)


class AcodisAuthError(AcodisApiError):
    def __init__(self, message):
        """Class for Acodis API authentication errors"""
        super().__init__(message)

    def __str__(self):
        return f"API Authentication error: {self.message}"


class AcodisParsingError(AcodisError):
    def __init__(self, message):
        """Class for Acodis result parsing errors"""
        super().__init__(message)
